@@ -1,7 +1,7 @@
 snowWrapper <-
 function(cl, seq, fun, cldata, name="cldata", lib=NULL, evalq=NULL,
-size = 1, balancing=c("none", "load", "size", "both"), dir = getwd(), 
-rng.type=c("none", "RNGstream", "SPRNG"), ...)
+size = 1, balancing=c("none", "load", "size", "both"), dir = NULL, 
+rng.type=c("none", "RNGstream", "SPRNG"), cleanup=TRUE, ...)
 {
     balancing <- match.arg(balancing)
     ## if object name exists in global env, make a copy as tmp, and put back in the end
@@ -21,7 +21,8 @@ rng.type=c("none", "RNGstream", "SPRNG"), ...)
         clusterSetupRNG(cl, type = rng.type)
     }
     ## sets common working directory
-    eval(parse(text=paste("clusterEvalQ(cl, setwd('", dir, "'))", sep="")))
+    if (!is.null(dir))
+        eval(parse(text=paste("clusterEvalQ(cl, setwd('", dir, "'))", sep="")))
     ## evaluates literal expressions if needed
     if (!is.null(evalq)) {
         for (i in evalq)
@@ -36,5 +37,7 @@ rng.type=c("none", "RNGstream", "SPRNG"), ...)
         "load" = clusterApplyLB(cl, seq, fun, ...),
         "size" = parLapplySB(cl, seq, size=size, fun, ...),
         "both" = parLapplySLB(cl, seq, size=size, fun, ...))
+    if (cleanup)
+        eval(parse(text=paste("clusterEvalQ(cl, rm(", name, "))")))
     res
 }
